@@ -33,7 +33,7 @@ def compute_sensitivity_factor(current_performance: float, target_performance: f
 
     return sensitivity_factor
 
-def compute_roi_sensitivity_factor_(revenue: float, cost: float, target_performance: float, units_spent: int, units_left: int, adjustment_cap: float=0.3):
+def compute_roi_sensitivity_factor(revenue: float, cost: float, target_performance: float, units_spent: int, units_left: int, adjustment_cap: float=0.3):
     """
     Function: compute_sensitivity_factor
 
